@@ -36,15 +36,14 @@ def web_server(*servers):
     if 'web_servers' not in env.roledefs:
         env.roledefs['web_servers'] = list(set(user_hosts))
     else:
-        env.roledefs.update({
-            'web_servers': list(set(env.roledefs['web_servers'] + user_hosts))
-        })
+        env.roledefs.update({'web_servers': list(set(env.roledefs['web_servers'] + user_hosts))})
 
 
 @beanstalk_task(beanstalk_role='app')
 def plant(VERBOSE=0):
     """plant beanstalk-stack for project in current work directory
     """
+    # TODO: Python Package
     set_verbose_level(VERBOSE)
     # Create beanstalk_stack home
     beanstalk_local_base_path = os.path.normpath(os.path.join(os.getcwd(), BEANSTALK_LOCAL_BASE_PATH))
@@ -191,11 +190,9 @@ def deploy(settings_path=None, **settings_patches):
 
             # We wanna preserve pyc/pyo files in our remote
             # Remove *.pyc, *.pyo, *.py[co] in ignore patterns and append "logs/" in the ignore file
-            local(
-                'sed -i.bak -e '
-                '\'/^\*\.py[c|o]$/d;/^\*\.py\[co\]$/d;$a\\\nlogs\/;$a\\\nvenv\/\''
-                ' {path} && rm -rf {path}.bak'.format(path='.gitignore')
-            )
+            local('sed -i.bak -e "/^\*\.py[c|o]$/d" {path} && rm -rf {path}.bak'.format(path='.gitignore'))
+            local('sed -i.bak -e \'$ a\\\nlogs/\' {path} && rm -rf {path}.bak'.format(path='.gitignore'))
+            local('sed -i.bak -e \'$ a\\\nvenv/\' {path} && rm -rf {path}.bak'.format(path='.gitignore'))
 
             # Check source code first
             run_hooked_actions('SOURCE_CHECK_ACTIONS')
